@@ -53,4 +53,15 @@ def convert_back(number,osn):
 
 def convert_to(number,osn1,osn2):
 	new_number = convert_back(number,osn1)
-	return convert(int(new_number),osn2)
\ No newline at end of file
+	return convert(int(new_number),osn2)
+
+def dividers(num):
+	dividers1 = [x for x in range(1, round(num**0.5) + 1) if num % x == 0]
+	dividers2 = [int(num / x) for x in reversed(dividers1) if int(num / x) not in dividers1]
+	return dividers1 + dividers2
+
+def prime(numbers):
+	if len(dividers(numbers))==2:
+		return True
+	else:
+		return False
